@@ -1,41 +1,72 @@
-#' @title  Twin Models Structure
+#' @title Twin Model Covariance Structures
 #' @author Wagner Hugo Bonat, \email{wbonat@@ufpr.br}
 #'
-#' @description The function \code{mc_twin} helps to build the components
-#' of the matrix linear predictor associated with ACDE models for
-#' analysis of twin data.
+#' @description
+#' Constructs the components of the matrix linear predictor for twin data
+#' analysis under ACDE-type models. The function generates covariance
+#' structures suitable for monozygotic (MZ) and dizygotic (DZ) twins and
+#' supports several biologically motivated and flexible model
+#' parameterizations.
 #'
-#' @param id name of the column (string) containing the twin index.
-#' It should be the same index (number) for both twins.
-#' @param twin.id name of the column (string) containing the twin index
-#' inside the pair. In general 1 for the first twin and 2 for the second
-#' twin.
-#' @param type name of the column (string) containing the indication of
-#' the twin as mz or dz. It should be a factor with only two levels mz and dz.
-#' Be sure that the reference level is mz.
-#' @param replicate name of the column (string) containing the index
-#' for more than one observation taken at the same twin pair. It is used
-#' for example in twin longitudinal studies. In that case, the replication
-#' column should contain the time index.
-#' @param formula internal.
-#' @param structure model type options are full, flex, uns, ACE, ADE,
-#' AE, CE and E. See example for details.
-#' @param data data set.
+#' @param id
+#' A string indicating the name of the column in \code{data} that
+#' identifies the twin pair. The same identifier must be shared by both
+#' twins in a pair.
 #'
-#' @source Bonat, W. H. (2018). Multiple Response Variables Regression
-#' Models in R: The mcglm Package. Journal of Statistical Software, 84(4):1--30.
+#' @param twin.id
+#' A string indicating the name of the column in \code{data} that
+#' identifies the twin within each pair. Typically coded as \code{1} and
+#' \code{2}.
 #'
-#' @return A list of matrices of \code{dgCMatrix} class.
+#' @param type
+#' A string indicating the name of the column in \code{data} that
+#' identifies the zygosity type. This variable must be a factor with
+#' exactly two levels: \code{"mz"} and \code{"dz"}, where \code{"mz"} is
+#' taken as the reference level.
 #'
-#' @seealso \code{mc_id}, \code{mc_dist}, \code{mc_car},
-#' \code{mc_rw}, \code{mc_ns}, \code{mc_dglm} and \code{mc_mixed}.
+#' @param replicate
+#' An optional string indicating the name of the column in \code{data}
+#' that identifies replicated observations within the same twin pair,
+#' such as time points in longitudinal twin studies. If provided, it is
+#' treated as a factor.
+#'
+#' @param formula
+#' Internal argument used to define flexible and unstructured covariance
+#' models. Not intended for direct user specification.
+#'
+#' @param structure
+#' A string specifying the covariance structure to be constructed.
+#' Available options are \code{"full"}, \code{"flex"}, \code{"uns"},
+#' \code{"ACE"}, \code{"ADE"}, \code{"AE"}, \code{"CE"} and \code{"E"}.
+#'
+#' @param data
+#' A data frame containing all variables referenced by the model.
+#'
+#' @details
+#' For biologically motivated structures (\code{"ACE"}, \code{"ADE"},
+#' \code{"AE"}, \code{"CE"}, \code{"E"}), the function builds covariance
+#' matrices based on classical twin modeling assumptions. For flexible
+#' and unstructured options (\code{"full"}, \code{"flex"}, \code{"uns"}),
+#' the covariance structure is constructed using matrix linear predictors.
+#'
+#' @return
+#' A list of sparse matrices of class \code{dgCMatrix}, representing the
+#' components of the matrix linear predictor to be used in the
+#' \code{matrix_pred} argument of \code{\link{mcglm}}.
+#'
+#' @source
+#' Bonat, W. H. (2018). Multiple Response Variables Regression Models in R:
+#' The mcglm Package. Journal of Statistical Software, 84(4), 1--30.
+#'
+#' @seealso
+#' \code{\link{mc_id}}, \code{\link{mc_dist}}, \code{\link{mc_car}},
+#' \code{\link{mc_rw}}, \code{\link{mc_ns}}, \code{\link{mc_dglm}},
+#' \code{\link{mc_mixed}}.
 #'
-#' @examples
-#' id <- rep(1:5, each = 4)
-#' id.twin <- rep(1:2, 10)
 #' @importFrom stats relevel
 #' @export
 
+
 mc_twin <- function(id, twin.id, type, replicate = NULL, structure, data) {
   # Checking the structure
   n_levels <- length(which(levels(data[[type]]) %in% c("mz","dz")))
@@ -152,8 +183,7 @@ mc_twin_bio <- function(id, twin.id, type, replicate = NULL,
   for(i in 1:length(data.twin)) {
     twin_temp <- data.twin[[i]]
     twin_temp$COD_ORDER1 <- 1:dim(twin_temp)[1]
-    #twin_temp <- twin_temp[order(twin_temp[twin.id]),]
-    twin_temp <- twin_temp[do.call(base::order, as.list(twin_temp[twin.id])),]
+    twin_temp <- twin_temp[order(twin_temp[twin.id]),]
     twin_temp$COD_ORDER2 <- 1:dim(twin_temp)[1]
     if(!is.null(replicate)) {
       n_replicate <- length(unique(twin_temp[[replicate]]))
@@ -164,13 +194,11 @@ mc_twin_bio <- function(id, twin.id, type, replicate = NULL,
       R_matrix <- Diagonal(n_replicate, 1)
     }
     if(unique(twin_temp[type]) == "mz") {
-      #twin_temp = twin_temp[order(twin_temp$COD_ORDER1),]
-      twin_temp <- twin_temp[do.call(base::order, as.list(twin_temp$COD_ORDER1)),]
+      twin_temp = twin_temp[order(twin_temp$COD_ORDER1),]
       M_temp <- kronecker(MZ, R_matrix)[twin_temp$COD_ORDER2,twin_temp$COD_ORDER2]
     }
     if(unique(twin_temp[type]) == "dz") {
-      #twin_temp = twin_temp[order(twin_temp$COD_ORDER1),]
-      twin_temp <- twin_temp[do.call(base::order, as.list(twin_temp$COD_ORDER1)),]
+      twin_temp = twin_temp[order(twin_temp$COD_ORDER1),]
       M_temp <- kronecker(DZ, R_matrix)[twin_temp$COD_ORDER2,twin_temp$COD_ORDER2]
     }
     M_list[[i]] <- M_temp
